==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DVirtualInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DVirtualInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cb2f27d0a15398e8 soot_dava_internal_javaRep_DVirtualInvokeExpr
// @dep_class 46b3dfa4f00e1a11 soot_grimp_internal_GVirtualInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class 63d0ad00bf9c0eff soot_jimple_internal_AbstractVirtualInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GVirtualInvokeExpr

#include "soot/grimp/internal/GVirtualInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DVirtualInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DVirtualInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$_init$e16b007df5f6f1c5(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_util_HashSet$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractVirtualInvokeExpr$vmethods	soot_jimple_internal_AbstractVirtualInvokeExpr;
	_jc_soot_grimp_internal_GVirtualInvokeExpr$vmethods	soot_grimp_internal_GVirtualInvokeExpr;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods	soot_dava_internal_javaRep_DVirtualInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs {
	struct _jc_java_util_HashSet$object	*thisLocals;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs	soot_dava_internal_javaRep_DVirtualInvokeExpr;
    _jc_soot_grimp_internal_GVirtualInvokeExpr$sub_refs	soot_grimp_internal_GVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_refs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_grimp_internal_GVirtualInvokeExpr$sub_nonrefs	soot_grimp_internal_GVirtualInvokeExpr;
    _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DVirtualInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DVirtualInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DVirtualInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DVirtualInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DVirtualInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cb2f27d0a15398e8 soot_dava_internal_javaRep_DVirtualInvokeExpr
// @dep_class 46b3dfa4f00e1a11 soot_grimp_internal_GVirtualInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class 63d0ad00bf9c0eff soot_jimple_internal_AbstractVirtualInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GVirtualInvokeExpr

#include "soot/grimp/internal/GVirtualInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DVirtualInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DVirtualInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$_init$e16b007df5f6f1c5(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_util_HashSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractVirtualInvokeExpr$vmethods	soot_jimple_internal_AbstractVirtualInvokeExpr;
	_jc_soot_grimp_internal_GVirtualInvokeExpr$vmethods	soot_grimp_internal_GVirtualInvokeExpr;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vmethods	soot_dava_internal_javaRep_DVirtualInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs {
	struct _jc_java_util_HashSet$object	*thisLocals;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_refs	soot_dava_internal_javaRep_DVirtualInvokeExpr;
    _jc_soot_grimp_internal_GVirtualInvokeExpr$sub_refs	soot_grimp_internal_GVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_refs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_grimp_internal_GVirtualInvokeExpr$sub_nonrefs	soot_grimp_internal_GVirtualInvokeExpr;
    _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DVirtualInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DVirtualInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DVirtualInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DVirtualInvokeExpr_H_ */
